@@ -16,23 +16,25 @@ if (!$verbose) {
 	$verbose = 0;
 }
 
+my $res = 1;
+
 if($program eq 1){
 	if ($verbose) {
 		print "GENERAL matrix\n";
 	}
-	system($^X, "-s", "./AnyMatrix/exe-RCommand.pl", "-f=$path", "-k=$parameter", "-d=$delta", "-verbose=$verbose") == 0 || die "failure";
+	$res = system($^X, "./AnyMatrix/exe-RCommand.pl", "-f=$path", "-k=$parameter", "-d=$delta", "-verbose=$verbose");
 }else{
 	if($program eq 2){
 		if ($verbose) {
 			print "BINARY matrix\n";	
 		}
-		system($^X, "-s", "./Binary/exe-RCommand.pl", "-f=$path", "-k=$parameter", "-verbose=$verbose") == 0 || die "failure";
+		$res = system($^X, "./Binary/exe-RCommand.pl", "-f=$path", "-k=$parameter", "-verbose=$verbose");
 	}else{
 		if($program eq 3){
 			if ($verbose) {
 				print "SPECIFIC matrix where N=M\n";
 			}
-			system($^X, "-s", "./SPECIFIC/exe-RCommand.pl" ,"-f=$path", "-k=$parameter", "-d=$delta", "-verbose=$verbose") == 0 || die "failure";
+			$res = system($^X, "./SPECIFIC/exe-RCommand.pl" ,"-f=$path", "-k=$parameter", "-d=$delta", "-verbose=$verbose");
 			
 		}else{
 			print "ERROR: Please specify -p=1, 2 or 3";
@@ -40,6 +42,6 @@ if($program eq 1){
 		}
 	}
 }
-exit 0;
+exit $res;
 	
 
